aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorbarrystyle <[email protected]>2021-02-20 20:13:43 +0800
committerGitHub <[email protected]>2021-02-20 12:13:43 +0000
commit8f77f8870dcff8d22c4339cd72269cf71a8b1265 (patch)
tree418715cc6d3f5f019f8e596b6b784d5247b67eec /src
parentMerge #20933: [0.21] doc: Archive release notes, Add template for minor release (diff)
downloaddiscoin-8f77f8870dcff8d22c4339cd72269cf71a8b1265.tar.xz
discoin-8f77f8870dcff8d22c4339cd72269cf71a8b1265.zip
1.21 codebase rebrand (#1711)
* build: Brand codebase as Dogecoin via automake/autoconf files. * build: Update internal resource files for windows builds. * build: Update internal application names and data directories. * build: Update immediately visible remaining bitcoin name references from cli binaries and qt. * build: Update immediately visible bitcoin references in the main gui itself. * Update functional tests to match Dogecoin * wallet: Add missing check for -descriptors wallet tool option * correct output for functional tests (errorlevels?) Co-authored-by: Ross Nicoll <[email protected]> Co-authored-by: MarcoFalke <[email protected]>
Diffstat (limited to 'src')
-rw-r--r--src/Makefile.am84
-rw-r--r--src/Makefile.bench.include28
-rw-r--r--src/Makefile.qt.include34
-rw-r--r--src/Makefile.qttest.include32
-rw-r--r--src/Makefile.test.include26
-rw-r--r--src/bench/.gitignore2
-rw-r--r--src/bitcoin-cli-res.rc10
-rw-r--r--src/bitcoin-cli.cpp18
-rw-r--r--src/bitcoin-tx-res.rc10
-rw-r--r--src/bitcoin-tx.cpp6
-rw-r--r--src/bitcoin-wallet-res.rc10
-rw-r--r--src/bitcoin-wallet.cpp13
-rw-r--r--src/bitcoind-res.rc10
-rw-r--r--src/bitcoind.cpp10
-rw-r--r--src/clientversion.cpp4
-rw-r--r--src/init.cpp2
-rw-r--r--src/policy/feerate.h4
-rw-r--r--src/qt/bitcoin.cpp2
-rw-r--r--src/qt/bitcoingui.cpp18
-rw-r--r--src/qt/bitcoinstrings.cpp2
-rw-r--r--src/qt/bitcoinunits.cpp23
-rw-r--r--src/qt/guiconstants.h12
-rw-r--r--src/qt/res/bitcoin-qt-res.rc8
-rw-r--r--src/qt/test/Makefile6
-rw-r--r--src/qt/utilitydialog.cpp2
-rw-r--r--src/test/amount_tests.cpp8
-rw-r--r--src/util/system.cpp16
-rw-r--r--src/wallet/sqlite.cpp2
-rw-r--r--src/wallet/wallettool.cpp13
29 files changed, 213 insertions, 202 deletions
diff --git a/src/Makefile.am b/src/Makefile.am
index c26cb3454..0331571a1 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -82,22 +82,22 @@ TESTS =
BENCHMARKS =
if BUILD_BITCOIND
- bin_PROGRAMS += bitcoind
+ bin_PROGRAMS += dogecoind
endif
if BUILD_BITCOIN_NODE
- bin_PROGRAMS += bitcoin-node
+ bin_PROGRAMS += dogecoin-node
endif
if BUILD_BITCOIN_CLI
- bin_PROGRAMS += bitcoin-cli
+ bin_PROGRAMS += dogecoin-cli
endif
if BUILD_BITCOIN_TX
- bin_PROGRAMS += bitcoin-tx
+ bin_PROGRAMS += dogecoin-tx
endif
if ENABLE_WALLET
if BUILD_BITCOIN_WALLET
- bin_PROGRAMS += bitcoin-wallet
+ bin_PROGRAMS += dogecoin-wallet
endif
endif
@@ -572,16 +572,16 @@ nodist_libbitcoin_util_a_SOURCES = $(srcdir)/obj/build.h
#
# bitcoind & bitcoin-node binaries #
-bitcoin_daemon_sources = bitcoind.cpp
-bitcoin_bin_cppflags = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES)
-bitcoin_bin_cxxflags = $(AM_CXXFLAGS) $(PIE_FLAGS)
-bitcoin_bin_ldflags = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
+dogecoin_daemon_sources = bitcoind.cpp
+dogecoin_bin_cppflags = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES)
+dogecoin_bin_cxxflags = $(AM_CXXFLAGS) $(PIE_FLAGS)
+dogecoin_bin_ldflags = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
if TARGET_WINDOWS
-bitcoin_daemon_sources += bitcoind-res.rc
+dogecoin_daemon_sources += bitcoind-res.rc
endif
-bitcoin_bin_ldadd = \
+dogecoin_bin_ldadd = \
$(LIBBITCOIN_WALLET) \
$(LIBBITCOIN_COMMON) \
$(LIBBITCOIN_UTIL) \
@@ -594,50 +594,50 @@ bitcoin_bin_ldadd = \
$(LIBMEMENV) \
$(LIBSECP256K1)
-bitcoin_bin_ldadd += $(BOOST_LIBS) $(BDB_LIBS) $(MINIUPNPC_LIBS) $(EVENT_PTHREADS_LIBS) $(EVENT_LIBS) $(ZMQ_LIBS) $(SQLITE_LIBS)
+dogecoin_bin_ldadd += $(BOOST_LIBS) $(BDB_LIBS) $(MINIUPNPC_LIBS) $(EVENT_PTHREADS_LIBS) $(EVENT_LIBS) $(ZMQ_LIBS) $(SQLITE_LIBS)
-bitcoind_SOURCES = $(bitcoin_daemon_sources)
-bitcoind_CPPFLAGS = $(bitcoin_bin_cppflags)
-bitcoind_CXXFLAGS = $(bitcoin_bin_cxxflags)
-bitcoind_LDFLAGS = $(bitcoin_bin_ldflags)
-bitcoind_LDADD = $(LIBBITCOIN_SERVER) $(bitcoin_bin_ldadd)
+dogecoind_SOURCES = $(dogecoin_daemon_sources)
+dogecoind_CPPFLAGS = $(dogecoin_bin_cppflags)
+dogecoind_CXXFLAGS = $(dogecoin_bin_cxxflags)
+dogecoind_LDFLAGS = $(dogecoin_bin_ldflags)
+dogecoind_LDADD = $(LIBBITCOIN_SERVER) $(dogecoin_bin_ldadd)
-bitcoin_node_SOURCES = $(bitcoin_daemon_sources)
-bitcoin_node_CPPFLAGS = $(bitcoin_bin_cppflags)
-bitcoin_node_CXXFLAGS = $(bitcoin_bin_cxxflags)
-bitcoin_node_LDFLAGS = $(bitcoin_bin_ldflags)
-bitcoin_node_LDADD = $(LIBBITCOIN_SERVER) $(bitcoin_bin_ldadd)
+dogecoin_node_SOURCES = $(dogecoin_daemon_sources)
+dogecoin_node_CPPFLAGS = $(dogecoin_bin_cppflags)
+dogecoin_node_CXXFLAGS = $(dogecoin_bin_cxxflags)
+dogecoin_node_LDFLAGS = $(dogecoin_bin_ldflags)
+dogecoin_node_LDADD = $(LIBBITCOIN_SERVER) $(dogecoin_bin_ldadd)
# bitcoin-cli binary #
-bitcoin_cli_SOURCES = bitcoin-cli.cpp
-bitcoin_cli_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(EVENT_CFLAGS)
-bitcoin_cli_CXXFLAGS = $(AM_CXXFLAGS) $(PIE_FLAGS)
-bitcoin_cli_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
+dogecoin_cli_SOURCES = bitcoin-cli.cpp
+dogecoin_cli_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(EVENT_CFLAGS)
+dogecoin_cli_CXXFLAGS = $(AM_CXXFLAGS) $(PIE_FLAGS)
+dogecoin_cli_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
if TARGET_WINDOWS
-bitcoin_cli_SOURCES += bitcoin-cli-res.rc
+dogecoin_cli_SOURCES += bitcoin-cli-res.rc
endif
-bitcoin_cli_LDADD = \
+dogecoin_cli_LDADD = \
$(LIBBITCOIN_CLI) \
$(LIBUNIVALUE) \
$(LIBBITCOIN_UTIL) \
$(LIBBITCOIN_CRYPTO)
-bitcoin_cli_LDADD += $(BOOST_LIBS) $(EVENT_LIBS)
+dogecoin_cli_LDADD += $(BOOST_LIBS) $(EVENT_LIBS)
#
# bitcoin-tx binary #
-bitcoin_tx_SOURCES = bitcoin-tx.cpp
-bitcoin_tx_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES)
-bitcoin_tx_CXXFLAGS = $(AM_CXXFLAGS) $(PIE_FLAGS)
-bitcoin_tx_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
+dogecoin_tx_SOURCES = bitcoin-tx.cpp
+dogecoin_tx_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES)
+dogecoin_tx_CXXFLAGS = $(AM_CXXFLAGS) $(PIE_FLAGS)
+dogecoin_tx_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
if TARGET_WINDOWS
-bitcoin_tx_SOURCES += bitcoin-tx-res.rc
+dogecoin_tx_SOURCES += bitcoin-tx-res.rc
endif
-bitcoin_tx_LDADD = \
+dogecoin_tx_LDADD = \
$(LIBUNIVALUE) \
$(LIBBITCOIN_COMMON) \
$(LIBBITCOIN_UTIL) \
@@ -645,18 +645,18 @@ bitcoin_tx_LDADD = \
$(LIBBITCOIN_CRYPTO) \
$(LIBSECP256K1)
-bitcoin_tx_LDADD += $(BOOST_LIBS)
+dogecoin_tx_LDADD += $(BOOST_LIBS)
#
# bitcoin-wallet binary #
-bitcoin_wallet_SOURCES = bitcoin-wallet.cpp
-bitcoin_wallet_CPPFLAGS = $(bitcoin_bin_cppflags)
-bitcoin_wallet_CXXFLAGS = $(bitcoin_bin_cxxflags)
-bitcoin_wallet_LDFLAGS = $(bitcoin_bin_ldflags)
-bitcoin_wallet_LDADD = $(LIBBITCOIN_WALLET_TOOL) $(bitcoin_bin_ldadd)
+dogecoin_wallet_SOURCES = bitcoin-wallet.cpp
+dogecoin_wallet_CPPFLAGS = $(dogecoin_bin_cppflags)
+dogecoin_wallet_CXXFLAGS = $(dogecoin_bin_cxxflags)
+dogecoin_wallet_LDFLAGS = $(dogecoin_bin_ldflags)
+dogecoin_wallet_LDADD = $(LIBBITCOIN_WALLET_TOOL) $(dogecoin_bin_ldadd)
if TARGET_WINDOWS
-bitcoin_wallet_SOURCES += bitcoin-wallet-res.rc
+dogecoin_wallet_SOURCES += bitcoin-wallet-res.rc
endif
#
diff --git a/src/Makefile.bench.include b/src/Makefile.bench.include
index beb3f8dfd..1bdfa9525 100644
--- a/src/Makefile.bench.include
+++ b/src/Makefile.bench.include
@@ -2,15 +2,15 @@
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
-bin_PROGRAMS += bench/bench_bitcoin
+bin_PROGRAMS += bench/bench_dogecoin
BENCH_SRCDIR = bench
-BENCH_BINARY = bench/bench_bitcoin$(EXEEXT)
+BENCH_BINARY = bench/bench_dogecoin$(EXEEXT)
RAW_BENCH_FILES = \
bench/data/block413567.raw
GENERATED_BENCH_FILES = $(RAW_BENCH_FILES:.raw=.raw.h)
-bench_bench_bitcoin_SOURCES = \
+bench_bench_dogecoin_SOURCES = \
$(RAW_BENCH_FILES) \
bench/addrman.cpp \
bench/bench_bitcoin.cpp \
@@ -45,11 +45,11 @@ bench_bench_bitcoin_SOURCES = \
bench/poly1305.cpp \
bench/prevector.cpp
-nodist_bench_bench_bitcoin_SOURCES = $(GENERATED_BENCH_FILES)
+nodist_bench_bench_dogecoin_SOURCES = $(GENERATED_BENCH_FILES)
-bench_bench_bitcoin_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(EVENT_CFLAGS) $(EVENT_PTHREADS_CFLAGS) -I$(builddir)/bench/
-bench_bench_bitcoin_CXXFLAGS = $(AM_CXXFLAGS) $(PIE_FLAGS)
-bench_bench_bitcoin_LDADD = \
+bench_bench_dogecoin_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(EVENT_CFLAGS) $(EVENT_PTHREADS_CFLAGS) -I$(builddir)/bench/
+bench_bench_dogecoin_CXXFLAGS = $(AM_CXXFLAGS) $(PIE_FLAGS)
+bench_bench_dogecoin_LDADD = \
$(LIBBITCOIN_SERVER) \
$(LIBBITCOIN_WALLET) \
$(LIBBITCOIN_COMMON) \
@@ -66,16 +66,16 @@ bench_bench_bitcoin_LDADD = \
$(EVENT_LIBS)
if ENABLE_ZMQ
-bench_bench_bitcoin_LDADD += $(LIBBITCOIN_ZMQ) $(ZMQ_LIBS)
+bench_bench_dogecoin_LDADD += $(LIBBITCOIN_ZMQ) $(ZMQ_LIBS)
endif
if ENABLE_WALLET
-bench_bench_bitcoin_SOURCES += bench/coin_selection.cpp
-bench_bench_bitcoin_SOURCES += bench/wallet_balance.cpp
+bench_bench_dogecoin_SOURCES += bench/coin_selection.cpp
+bench_bench_dogecoin_SOURCES += bench/wallet_balance.cpp
endif
-bench_bench_bitcoin_LDADD += $(BOOST_LIBS) $(BDB_LIBS) $(EVENT_PTHREADS_LIBS) $(EVENT_LIBS) $(MINIUPNPC_LIBS) $(SQLITE_LIBS)
-bench_bench_bitcoin_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
+bench_bench_dogecoin_LDADD += $(BOOST_LIBS) $(BDB_LIBS) $(EVENT_PTHREADS_LIBS) $(EVENT_LIBS) $(MINIUPNPC_LIBS) $(SQLITE_LIBS)
+bench_bench_dogecoin_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
CLEAN_BITCOIN_BENCH = bench/*.gcda bench/*.gcno $(GENERATED_BENCH_FILES)
@@ -83,13 +83,13 @@ CLEANFILES += $(CLEAN_BITCOIN_BENCH)
bench/data.cpp: bench/data/block413567.raw.h
-bitcoin_bench: $(BENCH_BINARY)
+dogecoin_bench: $(BENCH_BINARY)
bench: $(BENCH_BINARY) FORCE
$(BENCH_BINARY)
bitcoin_bench_clean : FORCE
- rm -f $(CLEAN_BITCOIN_BENCH) $(bench_bench_bitcoin_OBJECTS) $(BENCH_BINARY)
+ rm -f $(CLEAN_BITCOIN_BENCH) $(bench_bench_dogecoin_OBJECTS) $(BENCH_BINARY)
%.raw.h: %.raw
@$(MKDIR_P) $(@D)
diff --git a/src/Makefile.qt.include b/src/Makefile.qt.include
index f46310a60..4be106880 100644
--- a/src/Makefile.qt.include
+++ b/src/Makefile.qt.include
@@ -2,10 +2,10 @@
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
-bin_PROGRAMS += qt/bitcoin-qt
+bin_PROGRAMS += qt/dogecoin-qt
if BUILD_BITCOIN_GUI
- bin_PROGRAMS += bitcoin-gui
+ bin_PROGRAMS += dogecoin-gui
endif
EXTRA_LIBRARIES += qt/libbitcoinqt.a
@@ -301,7 +301,7 @@ QT_FORMS_H=$(join $(dir $(QT_FORMS_UI)),$(addprefix ui_, $(notdir $(QT_FORMS_UI:
# Most files will depend on the forms and moc files as includes. Generate them
# before anything else.
$(QT_MOC): $(QT_FORMS_H)
-$(qt_libbitcoinqt_a_OBJECTS) $(qt_bitcoin_qt_OBJECTS) $(bitcoin_gui_OBJECTS) : | $(QT_MOC)
+$(qt_libbitcoinqt_a_OBJECTS) $(qt_dogecoin_qt_OBJECTS) $(dogecoin_gui_OBJECTS) : | $(QT_MOC)
# bitcoin-qt and bitcoin-gui binaries #
bitcoin_qt_cppflags = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(BITCOIN_QT_INCLUDES) \
@@ -325,19 +325,19 @@ bitcoin_qt_ldadd += $(LIBBITCOIN_CLI) $(LIBBITCOIN_COMMON) $(LIBBITCOIN_UTIL) $(
bitcoin_qt_ldflags = $(RELDFLAGS) $(AM_LDFLAGS) $(QT_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
bitcoin_qt_libtoolflags = $(AM_LIBTOOLFLAGS) --tag CXX
-qt_bitcoin_qt_CPPFLAGS = $(bitcoin_qt_cppflags)
-qt_bitcoin_qt_CXXFLAGS = $(bitcoin_qt_cxxflags)
-qt_bitcoin_qt_SOURCES = $(bitcoin_qt_sources)
-qt_bitcoin_qt_LDADD = $(bitcoin_qt_ldadd)
-qt_bitcoin_qt_LDFLAGS = $(bitcoin_qt_ldflags)
-qt_bitcoin_qt_LIBTOOLFLAGS = $(bitcoin_qt_libtoolflags)
+qt_dogecoin_qt_CPPFLAGS = $(bitcoin_qt_cppflags)
+qt_dogecoin_qt_CXXFLAGS = $(bitcoin_qt_cxxflags)
+qt_dogecoin_qt_SOURCES = $(bitcoin_qt_sources)
+qt_dogecoin_qt_LDADD = $(bitcoin_qt_ldadd)
+qt_dogecoin_qt_LDFLAGS = $(bitcoin_qt_ldflags)
+qt_dogecoin_qt_LIBTOOLFLAGS = $(bitcoin_qt_libtoolflags)
-bitcoin_gui_CPPFLAGS = $(bitcoin_qt_cppflags)
-bitcoin_gui_CXXFLAGS = $(bitcoin_qt_cxxflags)
-bitcoin_gui_SOURCES = $(bitcoin_qt_sources)
-bitcoin_gui_LDADD = $(bitcoin_qt_ldadd)
-bitcoin_gui_LDFLAGS = $(bitcoin_qt_ldflags)
-bitcoin_gui_LIBTOOLFLAGS = $(bitcoin_qt_libtoolflags)
+dogecoin_gui_CPPFLAGS = $(bitcoin_qt_cppflags)
+dogecoin_gui_CXXFLAGS = $(bitcoin_qt_cxxflags)
+dogecoin_gui_SOURCES = $(bitcoin_qt_sources)
+dogecoin_gui_LDADD = $(bitcoin_qt_ldadd)
+dogecoin_gui_LDFLAGS = $(bitcoin_qt_ldflags)
+dogecoin_gui_LIBTOOLFLAGS = $(bitcoin_qt_libtoolflags)
#locale/foo.ts -> locale/foo.qm
QT_QM=$(QT_TS:.ts=.qm)
@@ -369,9 +369,9 @@ CLEAN_QT = $(nodist_qt_libbitcoinqt_a_SOURCES) $(QT_QM) $(QT_FORMS_H) qt/*.gcda
CLEANFILES += $(CLEAN_QT)
bitcoin_qt_clean: FORCE
- rm -f $(CLEAN_QT) $(qt_libbitcoinqt_a_OBJECTS) $(qt_bitcoin_qt_OBJECTS) qt/bitcoin-qt$(EXEEXT) $(LIBBITCOINQT)
+ rm -f $(CLEAN_QT) $(qt_libbitcoinqt_a_OBJECTS) $(qt_dogecoin_qt_OBJECTS) qt/dogecoin-qt$(EXEEXT) $(LIBBITCOINQT)
-bitcoin_qt : qt/bitcoin-qt$(EXEEXT)
+bitcoin_qt : qt/dogecoin-qt$(EXEEXT)
ui_%.h: %.ui
@test -f $(UIC)
diff --git a/src/Makefile.qttest.include b/src/Makefile.qttest.include
index c05dd3873..fd30d7a43 100644
--- a/src/Makefile.qttest.include
+++ b/src/Makefile.qttest.include
@@ -2,8 +2,8 @@
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
-bin_PROGRAMS += qt/test/test_bitcoin-qt
-TESTS += qt/test/test_bitcoin-qt
+bin_PROGRAMS += qt/test/test_dogecoin-qt
+TESTS += qt/test/test_dogecoin-qt
TEST_QT_MOC_CPP = \
qt/test/moc_apptests.cpp \
@@ -26,10 +26,10 @@ TEST_QT_H = \
qt/test/util.h \
qt/test/wallettests.h
-qt_test_test_bitcoin_qt_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(BITCOIN_QT_INCLUDES) \
+qt_test_test_dogecoin_qt_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(BITCOIN_QT_INCLUDES) \
$(QT_INCLUDES) $(QT_TEST_INCLUDES)
-qt_test_test_bitcoin_qt_SOURCES = \
+qt_test_test_dogecoin_qt_SOURCES = \
qt/test/apptests.cpp \
qt/test/compattests.cpp \
qt/test/rpcnestedtests.cpp \
@@ -38,36 +38,36 @@ qt_test_test_bitcoin_qt_SOURCES = \
qt/test/util.cpp \
$(TEST_QT_H)
if ENABLE_WALLET
-qt_test_test_bitcoin_qt_SOURCES += \
+qt_test_test_dogecoin_qt_SOURCES += \
qt/test/addressbooktests.cpp \
qt/test/wallettests.cpp \
wallet/test/wallet_test_fixture.cpp
endif # ENABLE_WALLET
-nodist_qt_test_test_bitcoin_qt_SOURCES = $(TEST_QT_MOC_CPP)
+nodist_qt_test_test_dogecoin_qt_SOURCES = $(TEST_QT_MOC_CPP)
-qt_test_test_bitcoin_qt_LDADD = $(LIBBITCOINQT) $(LIBBITCOIN_SERVER) $(LIBTEST_UTIL)
+qt_test_test_dogecoin_qt_LDADD = $(LIBBITCOINQT) $(LIBBITCOIN_SERVER) $(LIBTEST_UTIL)
if ENABLE_WALLET
-qt_test_test_bitcoin_qt_LDADD += $(LIBBITCOIN_UTIL) $(LIBBITCOIN_WALLET)
+qt_test_test_dogecoin_qt_LDADD += $(LIBBITCOIN_UTIL) $(LIBBITCOIN_WALLET)
endif
if ENABLE_ZMQ
-qt_test_test_bitcoin_qt_LDADD += $(LIBBITCOIN_ZMQ) $(ZMQ_LIBS)
+qt_test_test_dogecoin_qt_LDADD += $(LIBBITCOIN_ZMQ) $(ZMQ_LIBS)
endif
-qt_test_test_bitcoin_qt_LDADD += $(LIBBITCOIN_CLI) $(LIBBITCOIN_COMMON) $(LIBBITCOIN_UTIL) $(LIBBITCOIN_CONSENSUS) $(LIBBITCOIN_CRYPTO) $(LIBUNIVALUE) $(LIBLEVELDB) \
+qt_test_test_dogecoin_qt_LDADD += $(LIBBITCOIN_CLI) $(LIBBITCOIN_COMMON) $(LIBBITCOIN_UTIL) $(LIBBITCOIN_CONSENSUS) $(LIBBITCOIN_CRYPTO) $(LIBUNIVALUE) $(LIBLEVELDB) \
$(LIBLEVELDB_SSE42) $(LIBMEMENV) $(BOOST_LIBS) $(QT_DBUS_LIBS) $(QT_TEST_LIBS) $(QT_LIBS) \
$(QR_LIBS) $(BDB_LIBS) $(MINIUPNPC_LIBS) $(LIBSECP256K1) \
$(EVENT_PTHREADS_LIBS) $(EVENT_LIBS) $(SQLITE_LIBS)
-qt_test_test_bitcoin_qt_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(QT_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
-qt_test_test_bitcoin_qt_CXXFLAGS = $(AM_CXXFLAGS) $(QT_PIE_FLAGS)
+qt_test_test_dogecoin_qt_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(QT_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS)
+qt_test_test_dogecoin_qt_CXXFLAGS = $(AM_CXXFLAGS) $(QT_PIE_FLAGS)
CLEAN_BITCOIN_QT_TEST = $(TEST_QT_MOC_CPP) qt/test/*.gcda qt/test/*.gcno
CLEANFILES += $(CLEAN_BITCOIN_QT_TEST)
-test_bitcoin_qt : qt/test/test_bitcoin-qt$(EXEEXT)
+test_dogecoin_qt : qt/test/test_dogecoin-qt$(EXEEXT)
-test_bitcoin_qt_check : qt/test/test_bitcoin-qt$(EXEEXT) FORCE
+test_dogecoin_qt_check : qt/test/test_dogecoin-qt$(EXEEXT) FORCE
$(MAKE) check-TESTS TESTS=$^
-test_bitcoin_qt_clean: FORCE
- rm -f $(CLEAN_BITCOIN_QT_TEST) $(qt_test_test_bitcoin_qt_OBJECTS)
+test_dogecoin_qt_clean: FORCE
+ rm -f $(CLEAN_BITCOIN_QT_TEST) $(qt_test_test_dogecoin_qt_OBJECTS)
diff --git a/src/Makefile.test.include b/src/Makefile.test.include
index 9cc383c24..2b6de6cce 100644
--- a/src/Makefile.test.include
+++ b/src/Makefile.test.include
@@ -162,11 +162,11 @@ FUZZ_TARGETS = \
if ENABLE_FUZZ
noinst_PROGRAMS += $(FUZZ_TARGETS:=)
else
-bin_PROGRAMS += test/test_bitcoin
+bin_PROGRAMS += test/test_dogecoin
endif
TEST_SRCDIR = test
-TEST_BINARY=test/test_bitcoin$(EXEEXT)
+TEST_BINARY=test/test_dogecoin$(EXEEXT)
JSON_TEST_FILES = \
test/data/script_tests.json \
@@ -308,22 +308,22 @@ BITCOIN_TEST_SUITE += \
wallet/test/init_test_fixture.h
endif
-test_test_bitcoin_SOURCES = $(BITCOIN_TEST_SUITE) $(BITCOIN_TESTS) $(JSON_TEST_FILES) $(RAW_TEST_FILES)
-test_test_bitcoin_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(TESTDEFS) $(EVENT_CFLAGS)
-test_test_bitcoin_LDADD = $(LIBTEST_UTIL)
+test_test_dogecoin_SOURCES = $(BITCOIN_TEST_SUITE) $(BITCOIN_TESTS) $(JSON_TEST_FILES) $(RAW_TEST_FILES)
+test_test_dogecoin_CPPFLAGS = $(AM_CPPFLAGS) $(BITCOIN_INCLUDES) $(TESTDEFS) $(EVENT_CFLAGS)
+test_test_dogecoin_LDADD = $(LIBTEST_UTIL)
if ENABLE_WALLET
-test_test_bitcoin_LDADD += $(LIBBITCOIN_WALLET)
+test_test_dogecoin_LDADD += $(LIBBITCOIN_WALLET)
endif
-test_test_bitcoin_LDADD += $(LIBBITCOIN_SERVER) $(LIBBITCOIN_CLI) $(LIBBITCOIN_COMMON) $(LIBBITCOIN_UTIL) $(LIBBITCOIN_CONSENSUS) $(LIBBITCOIN_CRYPTO) $(LIBUNIVALUE) \
+test_test_dogecoin_LDADD += $(LIBBITCOIN_SERVER) $(LIBBITCOIN_CLI) $(LIBBITCOIN_COMMON) $(LIBBITCOIN_UTIL) $(LIBBITCOIN_CONSENSUS) $(LIBBITCOIN_CRYPTO) $(LIBUNIVALUE) \
$(LIBLEVELDB) $(LIBLEVELDB_SSE42) $(LIBMEMENV) $(BOOST_LIBS) $(BOOST_UNIT_TEST_FRAMEWORK_LIB) $(LIBSECP256K1) $(EVENT_LIBS) $(EVENT_PTHREADS_LIBS)
-test_test_bitcoin_CXXFLAGS = $(AM_CXXFLAGS) $(PIE_FLAGS)
+test_test_dogecoin_CXXFLAGS = $(AM_CXXFLAGS) $(PIE_FLAGS)
-test_test_bitcoin_LDADD += $(BDB_LIBS) $(MINIUPNPC_LIBS) $(SQLITE_LIBS)
-test_test_bitcoin_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS) -static
+test_test_dogecoin_LDADD += $(BDB_LIBS) $(MINIUPNPC_LIBS) $(SQLITE_LIBS)
+test_test_dogecoin_LDFLAGS = $(RELDFLAGS) $(AM_LDFLAGS) $(LIBTOOL_APP_LDFLAGS) $(PTHREAD_FLAGS) -static
if ENABLE_ZMQ
-test_test_bitcoin_LDADD += $(LIBBITCOIN_ZMQ) $(ZMQ_LIBS)
+test_test_dogecoin_LDADD += $(LIBBITCOIN_ZMQ) $(ZMQ_LIBS)
endif
if ENABLE_FUZZ
@@ -1262,7 +1262,7 @@ test_fuzz_uint256_deserialize_SOURCES = test/fuzz/deserialize.cpp
endif # ENABLE_FUZZ
-nodist_test_test_bitcoin_SOURCES = $(GENERATED_TEST_FILES)
+nodist_test_test_dogecoin_SOURCES = $(GENERATED_TEST_FILES)
$(BITCOIN_TESTS): $(GENERATED_TEST_FILES)
@@ -1284,7 +1284,7 @@ bitcoin_test_check: $(TEST_BINARY) FORCE
$(MAKE) check-TESTS TESTS=$^
bitcoin_test_clean : FORCE
- rm -f $(CLEAN_BITCOIN_TEST) $(test_test_bitcoin_OBJECTS) $(TEST_BINARY)
+ rm -f $(CLEAN_BITCOIN_TEST) $(test_test_dogecoin_OBJECTS) $(TEST_BINARY)
check-local: $(BITCOIN_TESTS:.cpp=.cpp.test)
if BUILD_BITCOIN_TX
diff --git a/src/bench/.gitignore b/src/bench/.gitignore
index e231fe4ca..306c2c174 100644
--- a/src/bench/.gitignore
+++ b/src/bench/.gitignore
@@ -1 +1 @@
-bench_bitcoin
+bench_dogecoin
diff --git a/src/bitcoin-cli-res.rc b/src/bitcoin-cli-res.rc
index 58f8f1e8a..1eaff9936 100644
--- a/src/bitcoin-cli-res.rc
+++ b/src/bitcoin-cli-res.rc
@@ -16,14 +16,14 @@ BEGIN
BEGIN
BLOCK "040904E4" // U.S. English - multilingual (hex)
BEGIN
- VALUE "CompanyName", "Bitcoin"
- VALUE "FileDescription", "bitcoin-cli (JSON-RPC client for " PACKAGE_NAME ")"
+ VALUE "CompanyName", "Dogecoin"
+ VALUE "FileDescription", "dogecoin-cli (JSON-RPC client for " PACKAGE_NAME ")"
VALUE "FileVersion", VER_FILEVERSION_STR
- VALUE "InternalName", "bitcoin-cli"
+ VALUE "InternalName", "dogecoin-cli"
VALUE "LegalCopyright", COPYRIGHT_STR
VALUE "LegalTrademarks1", "Distributed under the MIT software license, see the accompanying file COPYING or http://www.opensource.org/licenses/mit-license.php."
- VALUE "OriginalFilename", "bitcoin-cli.exe"
- VALUE "ProductName", "bitcoin-cli"
+ VALUE "OriginalFilename", "dogecoin-cli.exe"
+ VALUE "ProductName", "dogecoin-cli"
VALUE "ProductVersion", VER_PRODUCTVERSION_STR
END
END
diff --git a/src/bitcoin-cli.cpp b/src/bitcoin-cli.cpp
index ef4641cb6..573ad01f4 100644
--- a/src/bitcoin-cli.cpp
+++ b/src/bitcoin-cli.cpp
@@ -57,7 +57,7 @@ static void SetupCliArgs(ArgsManager& argsman)
argsman.AddArg("-version", "Print version and exit", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-conf=<file>", strprintf("Specify configuration file. Relative paths will be prefixed by datadir location. (default: %s)", BITCOIN_CONF_FILENAME), ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-datadir=<dir>", "Specify data directory", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
- argsman.AddArg("-generate", strprintf("Generate blocks immediately, equivalent to RPC generatenewaddress followed by RPC generatetoaddress. Optional positional integer arguments are number of blocks to generate (default: %s) and maximum iterations to try (default: %s), equivalent to RPC generatetoaddress nblocks and maxtries arguments. Example: bitcoin-cli -generate 4 1000", DEFAULT_NBLOCKS, DEFAULT_MAX_TRIES), ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+ argsman.AddArg("-generate", strprintf("Generate blocks immediately, equivalent to RPC generatenewaddress followed by RPC generatetoaddress. Optional positional integer arguments are number of blocks to generate (default: %s) and maximum iterations to try (default: %s), equivalent to RPC generatetoaddress nblocks and maxtries arguments. Example: dogecoin-cli -generate 4 1000", DEFAULT_NBLOCKS, DEFAULT_MAX_TRIES), ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-getinfo", "Get general information from the remote server. Note that unlike server-side RPC calls, the results of -getinfo is the result of multiple non-atomic requests. Some entries in the result may represent results from different states (e.g. wallet balance may be as of a different block from the chain state reported)", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-netinfo", "Get network peer connection information from the remote server. An optional integer argument from 0 to 4 can be passed for different peers listings (default: 0).", ArgsManager::ALLOW_INT, OptionsCategory::OPTIONS);
@@ -70,7 +70,7 @@ static void SetupCliArgs(ArgsManager& argsman)
argsman.AddArg("-rpcport=<port>", strprintf("Connect to JSON-RPC on <port> (default: %u, testnet: %u, signet: %u, regtest: %u)", defaultBaseParams->RPCPort(), testnetBaseParams->RPCPort(), signetBaseParams->RPCPort(), regtestBaseParams->RPCPort()), ArgsManager::ALLOW_ANY | ArgsManager::NETWORK_ONLY, OptionsCategory::OPTIONS);
argsman.AddArg("-rpcuser=<user>", "Username for JSON-RPC connections", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-rpcwait", "Wait for RPC server to start", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
- argsman.AddArg("-rpcwallet=<walletname>", "Send RPC for non-default wallet on RPC server (needs to exactly match corresponding -wallet option passed to bitcoind). This changes the RPC endpoint used, e.g. http://127.0.0.1:8332/wallet/<walletname>", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
+ argsman.AddArg("-rpcwallet=<walletname>", "Send RPC for non-default wallet on RPC server (needs to exactly match corresponding -wallet option passed to dogecoind). This changes the RPC endpoint used, e.g. http://127.0.0.1:8332/wallet/<walletname>", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-stdin", "Read extra arguments from standard input, one per line until EOF/Ctrl-D (recommended for sensitive information such as passphrases). When combined with -stdinrpcpass, the first line from standard input is used for the RPC password.", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-stdinrpcpass", "Read RPC password from standard input as a single line. When combined with -stdin, the first line from standard input is used for the RPC password. When combined with -stdinwalletpassphrase, -stdinrpcpass consumes the first line, and -stdinwalletpassphrase consumes the second.", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-stdinwalletpassphrase", "Read wallet passphrase from standard input as a single line. When combined with -stdin, the first line from standard input is used for the wallet passphrase.", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
@@ -118,10 +118,10 @@ static int AppInitRPC(int argc, char* argv[])
std::string strUsage = PACKAGE_NAME " RPC client version " + FormatFullVersion() + "\n";
if (!gArgs.IsArgSet("-version")) {
strUsage += "\n"
- "Usage: bitcoin-cli [options] <command> [params] Send command to " PACKAGE_NAME "\n"
- "or: bitcoin-cli [options] -named <command> [name=value]... Send command to " PACKAGE_NAME " (with named arguments)\n"
- "or: bitcoin-cli [options] help List commands\n"
- "or: bitcoin-cli [options] help <command> Get help for a command\n";
+ "Usage: dogecoin-cli [options] <command> [params] Send command to " PACKAGE_NAME "\n"
+ "or: dogecoin-cli [options] -named <command> [name=value]... Send command to " PACKAGE_NAME " (with named arguments)\n"
+ "or: dogecoin-cli [options] help List commands\n"
+ "or: dogecoin-cli [options] help <command> Get help for a command\n";
strUsage += "\n" + gArgs.GetHelpMessage();
}
@@ -377,7 +377,7 @@ public:
const UniValue& networkinfo{batch[ID_NETWORKINFO]["result"]};
if (networkinfo["version"].get_int() < 209900) {
- throw std::runtime_error("-netinfo requires bitcoind server to be running v0.21.0 and up");
+ throw std::runtime_error("-netinfo requires dogecoind server to be running v0.21.0 and up");
}
// Count peer connection totals, and if DetailsRequested(), store peer data in a vector of structs.
@@ -609,7 +609,7 @@ static UniValue CallRPC(BaseRequestHandler* rh, const std::string& strMethod, co
if (response.error != -1) {
responseErrorMessage = strprintf(" (error code %d - \"%s\")", response.error, http_errorstring(response.error));
}
- throw CConnectionFailed(strprintf("Could not connect to the server %s:%d%s\n\nMake sure the bitcoind server is running and that you are connecting to the correct RPC port.", host, port, responseErrorMessage));
+ throw CConnectionFailed(strprintf("Could not connect to the server %s:%d%s\n\nMake sure the dogecoind server is running and that you are connecting to the correct RPC port.", host, port, responseErrorMessage));
} else if (response.status == HTTP_UNAUTHORIZED) {
if (failedToGetAuthCookie) {
throw std::runtime_error(strprintf(
@@ -689,7 +689,7 @@ static void ParseError(const UniValue& error, std::string& strPrint, int& nRet)
strPrint += ("error message:\n" + err_msg.get_str());
}
if (err_code.isNum() && err_code.get_int() == RPC_WALLET_NOT_SPECIFIED) {
- strPrint += "\nTry adding \"-rpcwallet=<filename>\" option to bitcoin-cli command line.";
+ strPrint += "\nTry adding \"-rpcwallet=<filename>\" option to dogecoin-cli command line.";
}
} else {
strPrint = "error: " + error.write();
diff --git a/src/bitcoin-tx-res.rc b/src/bitcoin-tx-res.rc
index 3e49b820b..743d9ff30 100644
--- a/src/bitcoin-tx-res.rc
+++ b/src/bitcoin-tx-res.rc
@@ -16,14 +16,14 @@ BEGIN
BEGIN
BLOCK "040904E4" // U.S. English - multilingual (hex)
BEGIN
- VALUE "CompanyName", "Bitcoin"
- VALUE "FileDescription", "bitcoin-tx (CLI Bitcoin transaction editor utility)"
+ VALUE "CompanyName", "Dogecoin"
+ VALUE "FileDescription", "dogecoin-tx (CLI Dogecoin transaction editor utility)"
VALUE "FileVersion", VER_FILEVERSION_STR
- VALUE "InternalName", "bitcoin-tx"
+ VALUE "InternalName", "dogecoin-tx"
VALUE "LegalCopyright", COPYRIGHT_STR
VALUE "LegalTrademarks1", "Distributed under the MIT software license, see the accompanying file COPYING or http://www.opensource.org/licenses/mit-license.php."
- VALUE "OriginalFilename", "bitcoin-tx.exe"
- VALUE "ProductName", "bitcoin-tx"
+ VALUE "OriginalFilename", "dogecoin-tx.exe"
+ VALUE "ProductName", "dogecoin-tx"
VALUE "ProductVersion", VER_PRODUCTVERSION_STR
END
END
diff --git a/src/bitcoin-tx.cpp b/src/bitcoin-tx.cpp
index e22b3766c..7e4bb06c7 100644
--- a/src/bitcoin-tx.cpp
+++ b/src/bitcoin-tx.cpp
@@ -97,9 +97,9 @@ static int AppInitRawTx(int argc, char* argv[])
if (argc < 2 || HelpRequested(gArgs)) {
// First part of help message is specific to this utility
- std::string strUsage = PACKAGE_NAME " bitcoin-tx utility version " + FormatFullVersion() + "\n\n" +
- "Usage: bitcoin-tx [options] <hex-tx> [commands] Update hex-encoded bitcoin transaction\n" +
- "or: bitcoin-tx [options] -create [commands] Create hex-encoded bitcoin transaction\n" +
+ std::string strUsage = PACKAGE_NAME " dogecoin-tx utility version " + FormatFullVersion() + "\n\n" +
+ "Usage: dogecoin-tx [options] <hex-tx> [commands] Update hex-encoded bitcoin transaction\n" +
+ "or: dogecoin-tx [options] -create [commands] Create hex-encoded bitcoin transaction\n" +
"\n";
strUsage += gArgs.GetHelpMessage();
diff --git a/src/bitcoin-wallet-res.rc b/src/bitcoin-wallet-res.rc
index e9fa2dbb4..058f6f0b1 100644
--- a/src/bitcoin-wallet-res.rc
+++ b/src/bitcoin-wallet-res.rc
@@ -16,14 +16,14 @@ BEGIN
BEGIN
BLOCK "040904E4" // U.S. English - multilingual (hex)
BEGIN
- VALUE "CompanyName", "Bitcoin"
- VALUE "FileDescription", "bitcoin-wallet (CLI tool for " PACKAGE_NAME " wallets)"
+ VALUE "CompanyName", "Dogecoin"
+ VALUE "FileDescription", "dogecoin-wallet (CLI tool for " PACKAGE_NAME " wallets)"
VALUE "FileVersion", VER_FILEVERSION_STR
- VALUE "InternalName", "bitcoin-wallet"
+ VALUE "InternalName", "dogecoin-wallet"
VALUE "LegalCopyright", COPYRIGHT_STR
VALUE "LegalTrademarks1", "Distributed under the MIT software license, see the accompanying file COPYING or http://www.opensource.org/licenses/mit-license.php."
- VALUE "OriginalFilename", "bitcoin-wallet.exe"
- VALUE "ProductName", "bitcoin-wallet"
+ VALUE "OriginalFilename", "dogecoin-wallet.exe"
+ VALUE "ProductName", "dogecoin-wallet"
VALUE "ProductVersion", VER_PRODUCTVERSION_STR
END
END
diff --git a/src/bitcoin-wallet.cpp b/src/bitcoin-wallet.cpp
index b9c2fe2d3..10d61a0ee 100644
--- a/src/bitcoin-wallet.cpp
+++ b/src/bitcoin-wallet.cpp
@@ -26,7 +26,10 @@ static void SetupWalletToolArgs(ArgsManager& argsman)
argsman.AddArg("-datadir=<dir>", "Specify data directory", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-wallet=<wallet-name>", "Specify wallet name", ArgsManager::ALLOW_ANY | ArgsManager::NETWORK_ONLY, OptionsCategory::OPTIONS);
+ argsman.AddArg("-dumpfile=<file name>", "When used with 'dump', writes out the records to this file. When used with 'createfromdump', loads the records into a new wallet.", ArgsManager::ALLOW_STRING, OptionsCategory::OPTIONS);
argsman.AddArg("-debug=<category>", "Output debugging information (default: 0).", ArgsManager::ALLOW_ANY, OptionsCategory::DEBUG_TEST);
+ argsman.AddArg("-descriptors", "Create descriptors wallet. Only for 'create'", ArgsManager::ALLOW_BOOL, OptionsCategory::OPTIONS);
+ argsman.AddArg("-format=<format>", "The format of the wallet file to create. Either \"bdb\" or \"sqlite\". Only used with 'createfromdump'", ArgsManager::ALLOW_ANY, OptionsCategory::OPTIONS);
argsman.AddArg("-printtoconsole", "Send trace/debug info to console (default: 1 when no -debug is true, 0 otherwise).", ArgsManager::ALLOW_ANY, OptionsCategory::DEBUG_TEST);
argsman.AddArg("info", "Get wallet info", ArgsManager::ALLOW_ANY, OptionsCategory::COMMANDS);
@@ -43,12 +46,12 @@ static bool WalletAppInit(int argc, char* argv[])
return false;
}
if (argc < 2 || HelpRequested(gArgs)) {
- std::string usage = strprintf("%s bitcoin-wallet version", PACKAGE_NAME) + " " + FormatFullVersion() + "\n\n" +
- "bitcoin-wallet is an offline tool for creating and interacting with " PACKAGE_NAME " wallet files.\n" +
- "By default bitcoin-wallet will act on wallets in the default mainnet wallet directory in the datadir.\n" +
+ std::string usage = strprintf("%s dogecoin-wallet version", PACKAGE_NAME) + " " + FormatFullVersion() + "\n\n" +
+ "dogecoin-wallet is an offline tool for creating and interacting with " PACKAGE_NAME " wallet files.\n" +
+ "By default dogecoin-wallet will act on wallets in the default mainnet wallet directory in the datadir.\n" +
"To change the target wallet, use the -datadir, -wallet and -testnet/-regtest arguments.\n\n" +
"Usage:\n" +
- " bitcoin-wallet [options] <command>\n\n" +
+ " dogecoin-wallet [options] <command>\n\n" +
gArgs.GetHelpMessage();
tfm::format(std::cout, "%s", usage);
@@ -98,7 +101,7 @@ int main(int argc, char* argv[])
}
if (method.empty()) {
- tfm::format(std::cerr, "No method provided. Run `bitcoin-wallet -help` for valid methods.\n");
+ tfm::format(std::cerr, "No method provided. Run `dogecoin-wallet -help` for valid methods.\n");
return EXIT_FAILURE;
}
diff --git a/src/bitcoind-res.rc b/src/bitcoind-res.rc
index 3a64acd5d..99df2d3ae 100644
--- a/src/bitcoind-res.rc
+++ b/src/bitcoind-res.rc
@@ -16,14 +16,14 @@ BEGIN
BEGIN
BLOCK "040904E4" // U.S. English - multilingual (hex)
BEGIN
- VALUE "CompanyName", "Bitcoin"
- VALUE "FileDescription", "bitcoind (Bitcoin node with a JSON-RPC server)"
+ VALUE "CompanyName", "Dogecoin"
+ VALUE "FileDescription", "dogecoind (Dogecoin node with a JSON-RPC server)"
VALUE "FileVersion", VER_FILEVERSION_STR
- VALUE "InternalName", "bitcoind"
+ VALUE "InternalName", "dogecoind"
VALUE "LegalCopyright", COPYRIGHT_STR
VALUE "LegalTrademarks1", "Distributed under the MIT software license, see the accompanying file COPYING or http://www.opensource.org/licenses/mit-license.php."
- VALUE "OriginalFilename", "bitcoind.exe"
- VALUE "ProductName", "bitcoind"
+ VALUE "OriginalFilename", "dogecoind.exe"
+ VALUE "ProductName", "dogecoind"
VALUE "ProductVersion", VER_PRODUCTVERSION_STR
END
END
diff --git a/src/clientversion.cpp b/src/clientversion.cpp
index 993967a18..0a20b6906 100644
--- a/src/clientversion.cpp
+++ b/src/clientversion.cpp
@@ -9,10 +9,10 @@
/**
* Name of client reported in the 'version' message. Report the same name
- * for both bitcoind and bitcoin-qt, to make it harder for attackers to
+ * for both dogecoind and dogecoin-qt, to make it harder for attackers to
* target servers or GUI users specifically.
*/
-const std::string CLIENT_NAME("Satoshi");
+const std::string CLIENT_NAME("Shibetoshi");
#ifdef HAVE_BUILD_INFO
diff --git a/src/init.cpp b/src/init.cpp
index 6380da4f7..097c645f1 100644
--- a/src/init.cpp
+++ b/src/init.cpp
@@ -106,7 +106,7 @@ static const char* DEFAULT_ASMAP_FILENAME="ip_asn.map";
/**
* The PID file facilities.
*/
-static const char* BITCOIN_PID_FILENAME = "bitcoind.pid";
+static const char* BITCOIN_PID_FILENAME = "dogecoind.pid";
static fs::path GetPidFile(const ArgsManager& args)
{
diff --git a/src/policy/feerate.h b/src/policy/feerate.h
index 7c5660ac8..0ef97f63b 100644
--- a/src/policy/feerate.h
+++ b/src/policy/feerate.h
@@ -11,8 +11,8 @@
#include <string>
-const std::string CURRENCY_UNIT = "BTC"; // One formatted unit
-const std::string CURRENCY_ATOM = "sat"; // One indivisible minimum value unit
+const std::string CURRENCY_UNIT = "DOGE"; // One formatted unit
+const std::string CURRENCY_ATOM = "koinu"; // One indivisible minimum value unit
/* Used to determine type of fee estimation requested */
enum class FeeEstimateMode {
diff --git a/src/qt/bitcoin.cpp b/src/qt/bitcoin.cpp
index 63b4107f7..23c6f6e9d 100644
--- a/src/qt/bitcoin.cpp
+++ b/src/qt/bitcoin.cpp
@@ -194,7 +194,7 @@ void BitcoinCore::shutdown()
}
static int qt_argc = 1;
-static const char* qt_argv = "bitcoin-qt";
+static const char* qt_argv = "dogecoin-qt";
BitcoinApplication::BitcoinApplication():
QApplication(qt_argc, const_cast<char **>(&qt_argv)),
diff --git a/src/qt/bitcoingui.cpp b/src/qt/bitcoingui.cpp
index 23370e6ad..c432ecee6 100644
--- a/src/qt/bitcoingui.cpp
+++ b/src/qt/bitcoingui.cpp
@@ -249,7 +249,7 @@ void BitcoinGUI::createActions()
tabGroup->addAction(overviewAction);
sendCoinsAction = new QAction(platformStyle->SingleColorIcon(":/icons/send"), tr("&Send"), this);
- sendCoinsAction->setStatusTip(tr("Send coins to a Bitcoin address"));
+ sendCoinsAction->setStatusTip(tr("Send coins to a Dogecoin address"));
sendCoinsAction->setToolTip(sendCoinsAction->statusTip());
sendCoinsAction->setCheckable(true);
sendCoinsAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_2));
@@ -260,7 +260,7 @@ void BitcoinGUI::createActions()
sendCoinsMenuAction->setToolTip(sendCoinsMenuAction->statusTip());
receiveCoinsAction = new QAction(platformStyle->SingleColorIcon(":/icons/receiving_addresses"), tr("&Receive"), this);
- receiveCoinsAction->setStatusTip(tr("Request payments (generates QR codes and bitcoin: URIs)"));
+ receiveCoinsAction->setStatusTip(tr("Request payments (generates QR codes and dogecoin: URIs)"));
receiveCoinsAction->setToolTip(receiveCoinsAction->statusTip());
receiveCoinsAction->setCheckable(true);
receiveCoinsAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_3));
@@ -320,13 +320,13 @@ void BitcoinGUI::createActions()
changePassphraseAction = new QAction(tr("&Change Passphrase..."), this);
changePassphraseAction->setStatusTip(tr("Change the passphrase used for wallet encryption"));
signMessageAction = new QAction(tr("Sign &message..."), this);
- signMessageAction->setStatusTip(tr("Sign messages with your Bitcoin addresses to prove you own them"));
+ signMessageAction->setStatusTip(tr("Sign messages with your Dogecoin addresses to prove you own them"));
verifyMessageAction = new QAction(tr("&Verify message..."), this);
- verifyMessageAction->setStatusTip(tr("Verify messages to ensure they were signed with specified Bitcoin addresses"));
+ verifyMessageAction->setStatusTip(tr("Verify messages to ensure they were signed with specified Dogecoin addresses"));
m_load_psbt_action = new QAction(tr("&Load PSBT from file..."), this);
- m_load_psbt_action->setStatusTip(tr("Load Partially Signed Bitcoin Transaction"));
+ m_load_psbt_action->setStatusTip(tr("Load Partially Signed Dogecoin Transaction"));
m_load_psbt_clipboard_action = new QAction(tr("Load PSBT from clipboard..."), this);
- m_load_psbt_clipboard_action->setStatusTip(tr("Load Partially Signed Bitcoin Transaction from clipboard"));
+ m_load_psbt_clipboard_action->setStatusTip(tr("Load Partially Signed Dogecoin Transaction from clipboard"));
openRPCConsoleAction = new QAction(tr("Node window"), this);
openRPCConsoleAction->setStatusTip(tr("Open node debugging and diagnostic console"));
@@ -340,7 +340,7 @@ void BitcoinGUI::createActions()
usedReceivingAddressesAction->setStatusTip(tr("Show the list of used receiving addresses and labels"));
openAction = new QAction(tr("Open &URI..."), this);
- openAction->setStatusTip(tr("Open a bitcoin: URI"));
+ openAction->setStatusTip(tr("Open a dogecoin: URI"));
m_open_wallet_action = new QAction(tr("Open Wallet"), this);
m_open_wallet_action->setEnabled(false);
@@ -359,7 +359,7 @@ void BitcoinGUI::createActions()
showHelpMessageAction = new QAction(tr("&Command-line options"), this);
showHelpMessageAction->setMenuRole(QAction::NoRole);
- showHelpMessageAction->setStatusTip(tr("Show the %1 help message to get a list with possible Bitcoin command-line options").arg(PACKAGE_NAME));
+ showHelpMessageAction->setStatusTip(tr("Show the %1 help message to get a list with possible Dogecoin command-line options").arg(PACKAGE_NAME));
m_mask_values_action = new QAction(tr("&Mask values"), this);
m_mask_values_action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_M));
@@ -913,7 +913,7 @@ void BitcoinGUI::updateNetworkState()
QString tooltip;
if (m_node.getNetworkActive()) {
- tooltip = tr("%n active connection(s) to Bitcoin network", "", count) + QString(".<br>") + tr("Click to disable network activity.");
+ tooltip = tr("%n active connection(s) to Dogecoin network", "", count) + QString(".<br>") + tr("Click to disable network activity.");
} else {
tooltip = tr("Network activity disabled.") + QString("<br>") + tr("Click to enable network activity again.");
icon = ":/icons/network_disabled";
diff --git a/src/qt/bitcoinstrings.cpp b/src/qt/bitcoinstrings.cpp
index 27e512d07..658e49aa7 100644
--- a/src/qt/bitcoinstrings.cpp
+++ b/src/qt/bitcoinstrings.cpp
@@ -11,7 +11,7 @@
static const char UNUSED *bitcoin_strings[] = {
QT_TRANSLATE_NOOP("bitcoin-core", "The %s developers"),
QT_TRANSLATE_NOOP("bitcoin-core", ""
-"%s corrupt. Try using the wallet tool bitcoin-wallet to salvage or restoring "
+"%s corrupt. Try using the wallet tool dogecoin-wallet to salvage or restoring "
"a backup."),
QT_TRANSLATE_NOOP("bitcoin-core", ""
"-maxtxfee is set very high! Fees this large could be paid on a single "
diff --git a/src/qt/bitcoinunits.cpp b/src/qt/bitcoinunits.cpp
index fd55c547f..b9f496786 100644
--- a/src/qt/bitcoinunits.cpp
+++ b/src/qt/bitcoinunits.cpp
@@ -42,32 +42,27 @@ QString BitcoinUnits::longName(int unit)
{
switch(unit)
{
- case BTC: return QString("BTC");
- case mBTC: return QString("mBTC");
- case uBTC: return QString::fromUtf8("µBTC (bits)");
- case SAT: return QString("Satoshi (sat)");
+ case BTC: return QString("DOGE");
+ case mBTC: return QString("mDOGE");
+ case uBTC: return QString::fromUtf8("µDOGE");
+ case SAT: return QString("Koinu");
default: return QString("???");
}
}
QString BitcoinUnits::shortName(int unit)
{
- switch(unit)
- {
- case uBTC: return QString::fromUtf8("bits");
- case SAT: return QString("sat");
- default: return longName(unit);
- }
+ return longName(unit);
}
QString BitcoinUnits::description(int unit)
{
switch(unit)
{
- case BTC: return QString("Bitcoins");
- case mBTC: return QString("Milli-Bitcoins (1 / 1" THIN_SP_UTF8 "000)");
- case uBTC: return QString("Micro-Bitcoins (bits) (1 / 1" THIN_SP_UTF8 "000" THIN_SP_UTF8 "000)");
- case SAT: return QString("Satoshi (sat) (1 / 100" THIN_SP_UTF8 "000" THIN_SP_UTF8 "000)");
+ case BTC: return QString("Dogecoins");
+ case mBTC: return QString("Milli-Dogecoins (1 / 1" THIN_SP_UTF8 "000)");
+ case uBTC: return QString("Micro-Dogecoins (1 / 1" THIN_SP_UTF8 "000" THIN_SP_UTF8 "000)");
+ case SAT: return QString("Koinu (1 / 100" THIN_SP_UTF8 "000" THIN_SP_UTF8 "000)");
default: return QString("???");
}
}
diff --git a/src/qt/guiconstants.h b/src/qt/guiconstants.h
index 882d2c8f5..bd4ab6a74 100644
--- a/src/qt/guiconstants.h
+++ b/src/qt/guiconstants.h
@@ -42,12 +42,12 @@ static const int TOOLTIP_WRAP_THRESHOLD = 80;
/* Number of frames in spinner animation */
#define SPINNER_FRAMES 36
-#define QAPP_ORG_NAME "Bitcoin"
-#define QAPP_ORG_DOMAIN "bitcoin.org"
-#define QAPP_APP_NAME_DEFAULT "Bitcoin-Qt"
-#define QAPP_APP_NAME_TESTNET "Bitcoin-Qt-testnet"
-#define QAPP_APP_NAME_SIGNET "Bitcoin-Qt-signet"
-#define QAPP_APP_NAME_REGTEST "Bitcoin-Qt-regtest"
+#define QAPP_ORG_NAME "Dogecoin"
+#define QAPP_ORG_DOMAIN "dogecoin.com"
+#define QAPP_APP_NAME_DEFAULT "Dogecoin-Qt"
+#define QAPP_APP_NAME_TESTNET "Dogecoin-Qt-testnet"
+#define QAPP_APP_NAME_SIGNET "Dogecoin-Qt-signet"
+#define QAPP_APP_NAME_REGTEST "Dogecoin-Qt-regtest"
/* One gigabyte (GB) in bytes */
static constexpr uint64_t GB_BYTES{1000000000};
diff --git a/src/qt/res/bitcoin-qt-res.rc b/src/qt/res/bitcoin-qt-res.rc
index 94ae25647..d5d4c0e4f 100644
--- a/src/qt/res/bitcoin-qt-res.rc
+++ b/src/qt/res/bitcoin-qt-res.rc
@@ -19,13 +19,13 @@ BEGIN
BEGIN
BLOCK "040904E4" // U.S. English - multilingual (hex)
BEGIN
- VALUE "CompanyName", "Bitcoin"
- VALUE "FileDescription", PACKAGE_NAME " (GUI node for Bitcoin)"
+ VALUE "CompanyName", "Dogecoin"
+ VALUE "FileDescription", PACKAGE_NAME " (GUI node for Dogecoin)"
VALUE "FileVersion", VER_FILEVERSION_STR
- VALUE "InternalName", "bitcoin-qt"
+ VALUE "InternalName", "dogecoin-qt"
VALUE "LegalCopyright", COPYRIGHT_STR
VALUE "LegalTrademarks1", "Distributed under the MIT software license, see the accompanying file COPYING or http://www.opensource.org/licenses/mit-license.php."
- VALUE "OriginalFilename", "bitcoin-qt.exe"
+ VALUE "OriginalFilename", "dogecoin-qt.exe"
VALUE "ProductName", PACKAGE_NAME
VALUE "ProductVersion", VER_PRODUCTVERSION_STR
END
diff --git a/src/qt/test/Makefile b/src/qt/test/Makefile
index a02f86b62..47235ca82 100644
--- a/src/qt/test/Makefile
+++ b/src/qt/test/Makefile
@@ -1,6 +1,6 @@
all:
- $(MAKE) -C ../../ test_bitcoin_qt
+ $(MAKE) -C ../../ test_dogecoin_qt
clean:
- $(MAKE) -C ../../ test_bitcoin_qt_clean
+ $(MAKE) -C ../../ test_dogecoin_qt_clean
check:
- $(MAKE) -C ../../ test_bitcoin_qt_check
+ $(MAKE) -C ../../ test_dogecoin_qt_check
diff --git a/src/qt/utilitydialog.cpp b/src/qt/utilitydialog.cpp
index b7f85446f..388cf221e 100644
--- a/src/qt/utilitydialog.cpp
+++ b/src/qt/utilitydialog.cpp
@@ -58,7 +58,7 @@ HelpMessageDialog::HelpMessageDialog(QWidget *parent, bool about) :
ui->helpMessage->setVisible(false);
} else {
setWindowTitle(tr("Command-line options"));
- QString header = "Usage: bitcoin-qt [command-line options] \n";
+ QString header = "Usage: dogecoin-qt [command-line options] \n";
QTextCursor cursor(ui->helpMessage->document());
cursor.insertText(version);
cursor.insertBlock();
diff --git a/src/util/system.cpp b/src/util/system.cpp
index 5f30136fa..0cc19f67f 100644
--- a/src/util/system.cpp
+++ b/src/util/system.cpp
@@ -71,7 +71,7 @@
// Application startup time (used for uptime calculation)
const int64_t nStartupTime = GetTime();
-const char * const BITCOIN_CONF_FILENAME = "bitcoin.conf";
+const char * const BITCOIN_CONF_FILENAME = "dogecoin.conf";
const char * const BITCOIN_SETTINGS_FILENAME = "settings.json";
ArgsManager gArgs;
@@ -631,7 +631,7 @@ static std::string FormatException(const std::exception* pex, const char* pszThr
char pszModule[MAX_PATH] = "";
GetModuleFileNameA(nullptr, pszModule, sizeof(pszModule));
#else
- const char* pszModule = "bitcoin";
+ const char* pszModule = "dogecoin";
#endif
if (pex)
return strprintf(
@@ -650,12 +650,12 @@ void PrintExceptionContinue(const std::exception* pex, const char* pszThread)
fs::path GetDefaultDataDir()
{
- // Windows: C:\Users\Username\AppData\Roaming\Bitcoin
- // macOS: ~/Library/Application Support/Bitcoin
- // Unix-like: ~/.bitcoin
+ // Windows: C:\Users\Username\AppData\Roaming\Dogecoin
+ // macOS: ~/Library/Application Support/Dogecoin
+ // Unix-like: ~/.dogecoin
#ifdef WIN32
// Windows
- return GetSpecialFolderPath(CSIDL_APPDATA) / "Bitcoin";
+ return GetSpecialFolderPath(CSIDL_APPDATA) / "Dogecoin";
#else
fs::path pathRet;
char* pszHome = getenv("HOME");
@@ -665,10 +665,10 @@ fs::path GetDefaultDataDir()
pathRet = fs::path(pszHome);
#ifdef MAC_OSX
// macOS
- return pathRet / "Library/Application Support/Bitcoin";
+ return pathRet / "Library/Application Support/Dogecoin";
#else
// Unix-like
- return pathRet / ".bitcoin";
+ return pathRet / ".dogecoin";
#endif
#endif
}
diff --git a/src/wallet/sqlite.cpp b/src/wallet/sqlite.cpp
index d83332c19..5afa6ea3a 100644
--- a/src/wallet/sqlite.cpp
+++ b/src/wallet/sqlite.cpp
@@ -226,7 +226,7 @@ void SQLiteDatabase::Open()
// Now begin a transaction to acquire the exclusive lock. This lock won't be released until we close because of the exclusive locking mode.
ret = sqlite3_exec(m_db, "BEGIN EXCLUSIVE TRANSACTION", nullptr, nullptr, nullptr);
if (ret != SQLITE_OK) {
- throw std::runtime_error("SQLiteDatabase: Unable to obtain an exclusive lock on the database, is it being used by another bitcoind?\n");
+ throw std::runtime_error("SQLiteDatabase: Unable to obtain an exclusive lock on the database, is it being used by another dogecoind?\n");
}
ret = sqlite3_exec(m_db, "COMMIT", nullptr, nullptr, nullptr);
if (ret != SQLITE_OK) {
diff --git a/src/wallet/wallettool.cpp b/src/wallet/wallettool.cpp
index 0e18d6a74..28de5dc6a 100644
--- a/src/wallet/wallettool.cpp
+++ b/src/wallet/wallettool.cpp
@@ -109,6 +109,19 @@ bool ExecuteWalletToolFunc(const std::string& command, const std::string& name)
{
fs::path path = fs::absolute(name, GetWalletDir());
+ if (gArgs.IsArgSet("-format") && command != "createfromdump") {
+ tfm::format(std::cerr, "The -format option can only be used with the \"createfromdump\" command.\n");
+ return false;
+ }
+ if (gArgs.IsArgSet("-dumpfile") && command != "dump" && command != "createfromdump") {
+ tfm::format(std::cerr, "The -dumpfile option can only be used with the \"dump\" and \"createfromdump\" commands.\n");
+ return false;
+ }
+ if (gArgs.IsArgSet("-descriptors") && command != "create") {
+ tfm::format(std::cerr, "The -descriptors option can only be used with the 'create' command.\n");
+ return false;
+ }
+
if (command == "create") {
std::shared_ptr<CWallet> wallet_instance = MakeWallet(name, path, /* create= */ true);
if (wallet_instance) {
diff --git a/src/bitcoind.cpp b/src/bitcoind.cpp
index 455a82e39..1bcc73deb 100644
--- a/src/bitcoind.cpp
+++ b/src/bitcoind.cpp
@@ -45,7 +45,7 @@ static bool AppInit(int argc, char* argv[])
util::ThreadSetInternalName("init");
- // If Qt is used, parameters/bitcoin.conf are parsed in qt/bitcoin.cpp's main()
+ // If Qt is used, parameters/dogecoin.conf are parsed in qt/dogecoin.cpp's main()
SetupServerArgs(node);
ArgsManager& args = *Assert(node.args);
std::string error;
@@ -60,7 +60,7 @@ static bool AppInit(int argc, char* argv[])
if (args.IsArgSet("-version")) {
strUsage += FormatParagraph(LicenseInfo()) + "\n";
} else {
- strUsage += "\nUsage: bitcoind [options] Start " PACKAGE_NAME "\n";
+ strUsage += "\nUsage: dogecoind [options] Start " PACKAGE_NAME "\n";
strUsage += "\n" + args.GetHelpMessage();
}
@@ -87,7 +87,7 @@ static bool AppInit(int argc, char* argv[])
// Error out when loose non-argument tokens are encountered on command line
for (int i = 1; i < argc; i++) {
if (!IsSwitchChar(argv[i][0])) {
- return InitError(Untranslated(strprintf("Command line contains unexpected token '%s', see bitcoind -h for a list of options.\n", argv[i])));
+ return InitError(Untranslated(strprintf("Command line contains unexpected token '%s', see dogecoind -h for a list of options.\n", argv[i])));
}
}
@@ -96,7 +96,7 @@ static bool AppInit(int argc, char* argv[])
return false;
}
// -server defaults to true for bitcoind but not for the GUI so do this here
args.SoftSetBoolArg("-server", true);
// Set this early so that parameter interactions go to console
InitLogging(args);
@@ -166,7 +166,7 @@ int main(int argc, char* argv[])
#endif
SetupEnvironment();
// Connect bitcoind signal handlers
noui_connect();
return (AppInit(argc, argv) ? EXIT_SUCCESS : EXIT_FAILURE);
@@ -96,7 +96,7 @@ static bool AppInit(int argc, char* argv[])
return false;
}
- // -server defaults to true for bitcoind but not for the GUI so do this here
+ // -server defaults to true for dogecoind but not for the GUI so do this here
args.SoftSetBoolArg("-server", true);
// Set this early so that parameter interactions go to console
@@ -166,7 +166,7 @@ int main(int argc, char* argv[])
#endif
SetupEnvironment();
- // Connect bitcoind signal handlers
+ // Connect dogecoind signal handlers
noui_connect();
return (AppInit(argc, argv) ? EXIT_SUCCESS : EXIT_FAILURE);
diff --git a/src/test/amount_tests.cpp b/src/test/amount_tests.cpp
index c16519a6b..92f43eb76 100644
--- a/src/test/amount_tests.cpp
+++ b/src/test/amount_tests.cpp
@@ -98,7 +98,7 @@ BOOST_AUTO_TEST_CASE(BinaryOperatorTest)
BOOST_CHECK(a <= a);
BOOST_CHECK(b >= a);
BOOST_CHECK(b >= b);
// a should be 0.00000002 BTC/kvB now
a += a;
BOOST_CHECK(a == b);
}
@@ -107,9 +107,9 @@ BOOST_AUTO_TEST_CASE(ToStringTest)
{
CFeeRate feeRate;
feeRate = CFeeRate(1);
- BOOST_CHECK_EQUAL(feeRate.ToString(), "0.00000001 BTC/kvB");
- BOOST_CHECK_EQUAL(feeRate.ToString(FeeEstimateMode::BTC_KVB), "0.00000001 BTC/kvB");
- BOOST_CHECK_EQUAL(feeRate.ToString(FeeEstimateMode::SAT_VB), "0.001 sat/vB");
+ BOOST_CHECK_EQUAL(feeRate.ToString(), "0.00000001 DOGE/kvB");
+ BOOST_CHECK_EQUAL(feeRate.ToString(FeeEstimateMode::BTC_KVB), "0.00000001 DOGE/kvB");
+ BOOST_CHECK_EQUAL(feeRate.ToString(FeeEstimateMode::SAT_VB), "0.001 koinu/vB");
}
BOOST_AUTO_TEST_SUITE_END()
@@ -98,7 +98,7 @@ BOOST_AUTO_TEST_CASE(BinaryOperatorTest)
BOOST_CHECK(b >= a);
BOOST_CHECK(b >= b);
- // a should be 0.00000002 BTC/kvB now
+ // a should be 0.00000002 DOGE/kvB now
a += a;
BOOST_CHECK(a == b);